pub fn evaluate(graph: &Graph, cases: &[GoldenCase], limit: usize) -> EvalReportExpand description
Run every golden case through ground and aggregate the metrics, using the FROZEN ranker
calibration.
pub fn evaluate(graph: &Graph, cases: &[GoldenCase], limit: usize) -> EvalReportRun every golden case through ground and aggregate the metrics, using the FROZEN ranker
calibration.