pub fn callers(graph: &Graph, node_id: &str) -> Vec<Hit>Expand description
Direct callers/users of a node: reverse references edges (+ implements when the node is a
trait). Prefers function nodes — a containing type that only references the target through one
of its methods is dropped in favor of the method.