task_context_slice

Function task_context_slice 

pub fn task_context_slice(
    dag: &TaskDag,
    task_id: &str,
    available_context: &[TaskContextItem],
) -> Result<TaskContextSlice, TaskContextError>
Return the smallest useful context slice for one DAG task.

available_context is usually the focus pack that produced the DAG. Inputs that resolve to a context item are returned as read targets; other inputs are preserved as artifact inputs (context_pack, work_items, change_set, etc.).